==> MaachangComet-b1.15.zip: MaachangComet/src/MaachangComet/src/java/org/maachang/comet/MaachangDef.java <==
package org.maachang.comet ;

/**
 * MaachangComet定義.
 *
 * @version 2007/08/26
 * @author  masahito suzuki
 * @since   MaachangComet 1.00
 */
public class MaachangDef {
    
    private MaachangDef() {}
    
    /**
     * ディレクトリ : コンフィグ.
     */
    public static final String DIRECTORY_CONFIG = "conf/" ;
    
    /**
     * ディレクトリ : アプリケーション.
     */
    public static final String DIRECTORY_APPLICATION = "application/" ;
    
    /**
     * ディレクトリ : Modelディレクトリ.
     */
    public static final String DIRECTORY_MODEL = "model/" ;
    
    /**
     * ディレクトリ : ライブラリ用ディレクトリ.
     */
    public static final String DIRECTORY_LIB = "lib/" ;
    
    /**
     * ディレクトリ : JARファイル用ディレクトリ.
     */
    public static final String DIRECTORY_JAR = "jar/" ;
    
    /**
     * ディレクトリ : ログ出力用ディレクトリ.
     */
    public static final String DIRECTORY_LOG = "log/" ;
    
    /**
     * ディレクトリ : テーブル用ディレクトリ.
     */
    public static final String DIRECTORY_TABLE = "table/" ;
    
    /**
     * ディレクトリ : エラーページ用ディレクトリ.
     */
    public static final String DIRECTORY_ERROR_PAGE = "error/" ;
    
    /**
     * ディレクトリ : テンプレート用ディレクトリ.
     */
    public static final String DIRECTORY_TEMPLATE = "template/" ;
    
    /**
     * ディレクトリ : 公開ディレクトリ.
     */
    public static final String DIRECTORY_PUBLIC = "public/" ;
    
    /**
     * ディレクトリ : スタートアップディレクトリ.
     */
    public static final String DIRECTORY_STARTUP = "startup/" ;
    
    /**
     * ディレクトリ : 画像ディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_IMAGE = "img/" ;
    
    /**
     * ディレクトリ : 外部StyleSeetディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_CSS = "style/" ;
    
    /**
     * ディレクトリ : 外部JavaScriptディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_JS = "js/" ;

}

==> MaachangComet-b1.20.zip: MaachangComet/src/MaachangComet/src/java/org/maachang/comet/MaachangDef.java <==
package org.maachang.comet ;

/**
 * MaachangComet定義.
 *
 * @version 2007/08/26
 * @author  masahito suzuki
 * @since   MaachangComet 1.00
 */
public class MaachangDef {
    
    private MaachangDef() {}
    
    /**
     * ディレクトリ : コンフィグ.
     */
    public static final String DIRECTORY_CONFIG = "conf/" ;
    
    /**
     * ディレクトリ : アプリケーション.
     */
    public static final String DIRECTORY_APPLICATION = "application/" ;
    
    /**
     * ディレクトリ : Modelディレクトリ.
     */
    public static final String DIRECTORY_MODEL = "model/" ;
    
    /**
     * ディレクトリ : ライブラリ用ディレクトリ.
     */
    public static final String DIRECTORY_LIB = "lib/" ;
    
    /**
     * ディレクトリ : JARファイル用ディレクトリ.
     */
    public static final String DIRECTORY_JAR = "jar/" ;
    
    /**
     * ディレクトリ : ログ出力用ディレクトリ.
     */
    public static final String DIRECTORY_LOG = "log/" ;
    
    /**
     * ディレクトリ : テーブル用ディレクトリ.
     */
    public static final String DIRECTORY_TABLE = "table/" ;
    
    /**
     * ディレクトリ : エラーページ用ディレクトリ.
     */
    public static final String DIRECTORY_ERROR_PAGE = "error/" ;
    
    /**
     * ディレクトリ : テンプレート用ディレクトリ.
     */
    public static final String DIRECTORY_TEMPLATE = "template/" ;
    
    /**
     * ディレクトリ : 公開ディレクトリ.
     */
    public static final String DIRECTORY_PUBLIC = "public/" ;
    
    /**
     * ディレクトリ : スタートアップディレクトリ.
     */
    public static final String DIRECTORY_STARTUP = "startup/" ;
    
    /**
     * ディレクトリ : クーロン(スケジューリング)ディレクトリ.
     */
    public static final String DIRECTORY_CRON = "cron/" ;
    
    /**
     * ディレクトリ : タグライブラリディレクトリ.
     */
    public static final String DIRECTORY_TAGLIB = "taglib/" ;
    
    /**
     * ディレクトリ : 画像ディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_IMAGE = "img/" ;
    
    /**
     * ディレクトリ : 外部StyleSeetディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_CSS = "style/" ;
    
    /**
     * ディレクトリ : 外部JavaScriptディレクトリ[公開ディレクトリ配下に存在する].
     */
    public static final String DIRECTORY_JS = "js/" ;

}
